"""Top-level package for qnorm."""
from .quantile_normalize import quantile_normalize

__all__ = [
    "quantile_normalize"
]
__author__ = "Maarten van der Sande"
__email__ = "maartenvandersande[at]gmail.com"
__version__ = "0.0.7"
